aboutsummaryrefslogtreecommitdiff
path: root/arch/x86_64/src/memory/paging_root.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'arch/x86_64/src/memory/paging_root.cpp')
-rw-r--r--arch/x86_64/src/memory/paging_root.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/arch/x86_64/src/memory/paging_root.cpp b/arch/x86_64/src/memory/paging_root.cpp
index d849a82..41f40ed 100644
--- a/arch/x86_64/src/memory/paging_root.cpp
+++ b/arch/x86_64/src/memory/paging_root.cpp
@@ -1,9 +1,9 @@
-#include "x86_64/memory/paging_root.hpp"
+#include "arch/memory/paging_root.hpp"
#include <bit>
#include <cstdint>
-namespace teachos::memory::x86_64
+namespace arch::memory
{
namespace
@@ -16,4 +16,4 @@ namespace teachos::memory::x86_64
return std::bit_cast<paging_root *>(recursive_base);
}
-} // namespace teachos::memory::x86_64 \ No newline at end of file
+} // namespace arch::memory \ No newline at end of file